import React from 'react';
import '../../css/style.css';
import App from "./App";
import * as d3 from "d3";

class Nombreventes extends React.Component {

  type = {
    ANNEE: 'year',
    MOIS: 'month',
    JOURS: 'day'
  }

  constructor(props) {
    super(props);

    this.state = {
      data: [],
      type: this.type.ANNEE,
      startDate: '2015-07-01',
      endDate: '2020-06-30'
    }

    this.handleChangeType = this.handleChangeType.bind(this);
    this.handleChangeStart = this.handleChangeStart.bind(this);
    this.handleChangeEnd = this.handleChangeEnd.bind(this);
  }

  handleChangeType(event) {
    this.setState({type: event.target.value}, this.getData);
  }

  handleChangeStart(event) {
    this.setState({startDate: event.target.value}, this.getData);
  }

  handleChangeEnd(event) {
    this.setState({endDate: event.target.value}, this.getData);
  }

  drawChart() {
    const data = this.state.data
    const width = 800;
    const height = 450;
    const svg = d3.select("#nbVentesGraph").html("")
      .append('svg')
      .attr('id', 'chart')
      .attr('width', width)
      .attr('height', height);
    const margin = {
      top: 60,
      bottom: 100,
      left: 80,
      right: 40
    };

    const chart = svg.append('g')
      .classed('display', true)
      .attr('transform', `translate(${margin.left},${margin.top})`);

    const chartWidth = width - margin.left - margin.right;
    const chartHeight = height - margin.top - margin.bottom;

    const xScale = d3.scaleBand()
      .domain(data.map(d => d.unit))
      .range([0, chartWidth]);
    const yScale = d3.scaleLinear()
      .domain([0, d3.max(data, d => d.nombre_de_vente)])
      .range([chartHeight, 0]);
    const colorScale = d3.scaleOrdinal(d3.schemeCategory10);
    chart.selectAll(".bar")
      .data(data)
      .enter()
      .append('rect')
      .classed('bar', true)
      .attr('x', d => xScale(d.unit))
      .attr('y', d => yScale(d.nombre_de_vente))
      .attr('height', d => (chartHeight - yScale(d.nombre_de_vente)))
      .attr('width', d => xScale.bandwidth())
      .style('fill', (d, i) => colorScale(i));

    chart.selectAll('.bar-label')
      .data(data)
      .enter()
      .append('text')
      .classed('bar-label', true)
      .attr('x', d => xScale(d.unit) + xScale.bandwidth() / 2)
      .attr('dx', 0)
      .attr('y', d => yScale(d.nombre_de_vente))
      .attr('dy', -6)
      .text(d => d.value);

    const xAxis = d3.axisBottom()
      .scale(xScale);

    chart.append('g')
     .classed('x axis', true)
     .attr('transform', `translate(0,${chartHeight})`)
     .call(xAxis);

     const yAxis = d3.axisLeft()
     .ticks(5)
     .scale(yScale);

     chart.append('g')
     .classed('y axis', true)
     .attr('transform', 'translate(0,0)')
     .call(yAxis);

    chart.select('.x.axis')
      .append('text')
      .attr('x',  chartWidth/2)
      .attr('y', 60)
      .attr('fill', '#000')
      .style('font-size', '20px')
      .style('text-anchor', 'middle')
      .text('Date');

    chart.select('.y.axis')
      .append('text')
      .attr('x', 0)
      .attr('y', 0)
      .attr('transform', `translate(-50, ${chartHeight/2}) rotate(-90)`)
      .attr('fill', '#000')
      .style('font-size', '20px')
      .style('text-anchor', 'middle')
      .text('Nombre de ventes');
  }

  getData() {
    d3.select("#nbVentesGraph").html("Chargement ...")
    console.log(`https://${document.domain}:8443/nombre-ventes/${this.state.type}/${this.state.startDate}/${this.state.endDate}`)
    fetch(`https://${document.domain}:8443/nombre-ventes/${this.state.type}/${this.state.startDate}/${this.state.endDate}`)
      .then(response => {
        if (response.ok) {
          return response.json();
        } else {
          throw new Error('error');
        }
      })
      .then(data => {
        this.setState({data: data});
        console.log(data);
        this.drawChart();
      })
      .catch(error => console.log("error"));
  }

  componentDidMount() {
    this.getData();
  }

  render() {
    return (
      <div>
        <App/>
        <h1>Nombre de ventes</h1>
        <label htmlFor="type">Type : </label>
        <select id="type" value={this.state.type} onChange={this.handleChangeType}>
          <option value="year">Annee</option>
          <option value="month">Mois</option>
          <option value="day">Jour</option>
        </select>

        <label htmlFor="start">From :</label>

        <input type="date" id="start"
               value={this.state.startDate}
               min="2015-07-01" max="2020-06-30" onChange={this.handleChangeStart}/>

        <label htmlFor="end">To :</label>

        <input type="date" id="end"
               value={this.state.endDate}
               min="2015-07-01" max="2020-06-30" onChange={this.handleChangeEnd}/>

        <div id="nbVentesGraph"></div>

      </div>
    )
  }
}

export default Nombreventes;


